OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "Favorites" : "Preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote account\"" : "\"account remoto\"",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user} ha ripristinato {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Hai rinominato {oldfile} (nascosto) in {newfile} (nascosto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Hai rinominato {oldfile} (nascosto) in {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Hai rinominato {oldfile} in {newfile} (nascosto)",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ha rinominato {oldfile} (nascosto) in {newfile} (nascosto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ha rinominato {oldfile} (nascosto) in {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ha rinominato {oldfile} in {newfile} (nascosto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "Files" : "File",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un file preferito o una cartella è stato <strong>modificato</strong>",
    "Failed to authorize" : "Impossibile dare l'autorizzazione",
    "Invalid folder path" : "Percorso della cartella non valido",
    "Folder not found" : "Cartella non trovata",
    "The file cannot be found" : "Il file non può essere trovato",
    "The destination path does not exist: %1$s" : "Il percorso di destinazione non esiste: %1$s",
    "You do not have permission to create a file at the specified location" : "Non hai l'autorizzazione per creare un file nella posizione specificata",
    "The file could not be converted." : "Il file non può essere convertito.",
    "Could not get relative path to converted file" : "Impossibile ottenere il percorso relativo al file convertito",
    "Limit must be a positive integer." : "Il limite deve essere un numero intero positivo.",
    "The replacement character may only be a single character." : "Il carattere sostitutivo può essere un solo carattere.",
    "Filename sanitization already started." : "La sanificazione del nome file è già iniziata.",
    "No filename sanitization in progress." : "Nessuna sanificazione del nome file in corso.",
    "Favorite files" : "File preferiti",
    "No favorites" : "Nessun preferito",
    "More favorites" : "Altri preferiti",
    "Accept" : "Accetta",
    "Reject" : "Rifiuta",
    "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingresso da {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vuoi accettare {path}?\n\nNota: il processo di trasferimento dopo l'accettazione potrebbe richiedere fino a un'ora.",
    "Ownership transfer denied" : "Trasferimento di proprietà negato",
    "Your ownership transfer of {path} was denied by {user}." : "Il tuo trasferimento di proprietà di {path} è stato negato da {user}.",
    "Ownership transfer failed" : "Trasferimento di proprietà non riuscito",
    "Your ownership transfer of {path} to {user} failed." : "Il tuo trasferimento di proprietà di {path} a {user} non è riuscito.",
    "The ownership transfer of {path} from {user} failed." : "Il trasferimento di proprietà di {path} da {user} non è riuscito.",
    "Ownership transfer done" : "Trasferimento di proprietà completato",
    "Your ownership transfer of {path} to {user} has completed." : "Il tuo trasferimento di proprietà di {path} a {user} è completato.",
    "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
    "in %s" : "in %s",
    "Transferred from %1$s on %2$s" : "Trasferito da %1$s su %2$s",
    "File Management" : "Gestione dei file",
    "Home" : "Home",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Reload current directory" : "Ricarica la cartella corrente",
    "Go to the \"{dir}\" directory" : "Vai alla cartella \"{dir}\"",
    "Current directory path" : "Percorso della cartella corrente",
    "Share" : "Condividi",
    "Reload content" : "Ricarica il contenuto",
    "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
    "You do not have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
    "Drag and drop files here to upload" : "Trascina e rilascia i file qui per caricarli",
    "Favorite" : "Preferito",
    "Back" : "Indietro",
    "Toggle selection for file \"{displayName}\"" : "Attiva/disattiva la selezione per il file \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Attiva/disattiva la selezione per la cartella \"{displayName}\"",
    "File is loading" : "Il file è in caricamento",
    "Folder is loading" : "La cartella è in caricamento",
    "Filename" : "Nome file",
    "Folder name" : "Nome della cartella",
    "This node is unavailable" : "Questa nodo non è disponibile",
    "Another entry with the same name already exists." : "Esiste già un'altra voce con lo stesso nome.",
    "Invalid filename." : "Nome di file non valido.",
    "Rename file" : "Rinomina file",
    "Folder" : "Cartella",
    "Unknown file type" : "Tipo di file sconosciuto",
    "{ext} image" : "{ext} image",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} audio",
    "{ext} text" : "{ext} text",
    "Pending" : "In corso",
    "Unknown date" : "Data sconosciuta",
    "Active filters" : "Filtri attivi",
    "Remove filter" : "Rimuovi filtro",
    "Today" : "Oggi",
    "Last 7 days" : "Ultimi 7 giorni",
    "Last 30 days" : "Ultimi 30 giorni",
    "This year ({year})" : "Quest'anno ({year})",
    "Last year ({year})" : "L'anno scorso ({year})",
    "Custom range" : "Intervallo personalizzato",
    "Custom date range" : "Intervallo di date personalizzato",
    "Search everywhere" : "Cerca ovunque",
    "Documents" : "Documenti",
    "Spreadsheets" : "Fogli elettronici",
    "Presentations" : "Presentazioni",
    "PDFs" : "PDF",
    "Folders" : "Cartelle",
    "Audio" : "Audio",
    "Images" : "Immagini",
    "Videos" : "Video",
    "Filters" : "Filtri",
    "Back to filters" : "Torna ai filtri",
    "Appearance" : "Aspetto",
    "Show hidden files" : "Mostra i file nascosti",
    "Show file type column" : "Mostra colonna tipo di file",
    "Show file extensions" : "Mostra estensioni di file",
    "Crop image previews" : "Ritaglia le anteprime delle immagini",
    "General" : "Generale",
    "Sort favorites first" : "Ordina prima i preferiti",
    "Sort folders before files" : "Ordina cartelle prima dei files",
    "Enable folder tree view" : "Abilita visuale ad albero delle cartelle",
    "Default view" : "Vista predefinita",
    "All files" : "Tutti i file",
    "Personal files" : "File personali",
    "Additional settings" : "Impostazioni aggiuntive",
    "Actions" : "Azioni",
    "File actions" : "Azioni sui file",
    "Selection" : "Selezione",
    "Select all files" : "Seleziona tutti i file",
    "Deselect all" : "Deseleziona tutto",
    "Select or deselect" : "Seleziona o deseleziona",
    "Select a range" : "Seleziona un intervallo",
    "Navigation" : "Navigazione",
    "Go to parent folder" : "Vai alla cartella padre",
    "Go to file above" : "Vai al file sopra",
    "Go to file below" : "Vai al file sotto",
    "Go left in grid" : "Vai a sinistra nella griglia",
    "Go right in grid" : "Vai a destra nella griglia",
    "View" : "Visualizza",
    "Toggle grid view" : "Commuta la vista a griglia",
    "Show those shortcuts" : "Mostra quelle scorciatoie",
    "Warnings" : "Avvertenze",
    "Warn before changing a file extension" : "Avvisa prima di modificare l'estensione di un file",
    "Warn before deleting a file" : "Avvisa prima di eliminare un file",
    "WebDAV URL" : "URL WebDAV",
    "Create an app password" : "Crea una nuova password di applicazione",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Richiesto per l'autenticazione WebDAV perché l'autenticazione a due fattori è abilitata per questo account.",
    "How to access files using WebDAV" : "Come accedere ai file tramite WebDAV",
    "Total rows summary" : "Riepilogo totale delle righe",
    "Toggle selection for all files and folders" : "Attiva/disattiva la selezione per tutti i file e le cartelle",
    "Name" : "Nome",
    "File type" : "Tipo di file",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "{displayName}: failed on some elements" : "{displayName}: non riuscito su alcuni elementi",
    "{displayName}: done" : "{displayName}: fatto",
    "{displayName}: failed" : "{displayName}: non riuscito",
    "(selected)" : "(selezionato)",
    "List of files and folders." : "Lista di file e cartelle.",
    "You have used your space quota and cannot upload files anymore." : "Hai esaurito la tua quota di spazio e non puoi più caricare file.",
    "Column headers with buttons are sortable." : "Le intestazioni di colonna con pulsanti sono ordinabili.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Questa lista non è stata mostrata completamente per ragioni di prestazioni. I file verranno mostrati durante la navigazione della lista.",
    "File not found" : "File non trovato",
    "_{count} selected_::_{count} selected_" : ["{count} selezionato","{count} selezionati","{count} selezionati"],
    "Search everywhere …" : "Cerca ovunque …",
    "Search here …" : "Cerca qui …",
    "Search scope options" : "Opzioni nell'ambito di ricerca",
    "Search here" : "Cerca qui",
    "Owner" : "Proprietario",
    "{usedQuotaByte} used" : "{usedQuotaByte} usato",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{relative}% used" : "{relative}% usato",
    "Could not refresh storage stats" : "Impossibile aggiornare le statistiche di archiviazione",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage information" : "Informazioni di archiviazione",
    "Storage quota" : "Limite di archiviazione",
    "New folder" : "Nuova cartella",
    "Create new folder" : "Crea una nuova cartella",
    "This name is already in use." : "Questo nome è già utilizzato.",
    "Create" : "Crea",
    "Files starting with a dot are hidden by default" : "I file che iniziano con un punto sono nascosti per impostazione predefinita",
    "Failed to start filename sanitization." : "Impossibile avviare la sanificazione del nome file.",
    "Failed to refresh filename sanitization status." : "Impossibile aggiornare lo stato di sanificazione del nome file.",
    "Filename sanitization in progress." : "Sanificazione del nome del file in corso.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Attualmente {processedUsers} di{totalUsers} account sono già stati elaborati.",
    "Preparing …" : "Preparazione …",
    "Refresh" : "Aggiorna",
    "All files have been santized for Windows filename support." : "Tutti i file sono stati abilitati per supportare i nomi file di Windows.",
    "Some files could not be sanitized, please check your logs." : "Alcuni file non possono essere ripuliti, controlla i tuoi log.",
    "Sanitization errors" : "Errori di sanificazione",
    "Not sanitized filenames" : "Nomi di file non sanificati",
    "Windows filename support has been enabled." : "È stato abilitato il supporto per i nomi file di Windows.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Sebbene ciò impedisca agli utenti di creare nuovi file con nomi non supportati, i file esistenti non sono ancora stati rinominati e pertanto potrebbero comunque interrompere la sincronizzazione su Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "È possibile attivare la rinomina dei file con nomi non validi; questa operazione verrà eseguita in background e potrebbe richiedere del tempo.",
    "Please note that this may cause high workload on the sync clients." : "Si prega di notare che ciò potrebbe causare un carico di lavoro elevato sui client di sincronizzazione.",
    "Limit" : "Limite",
    "This allows to configure how many users should be processed in one background job run." : "Ciò consente di configurare quanti utenti devono essere elaborati in un'esecuzione di un processo in background.",
    "Sanitize filenames" : "Sanificare i nomi dei file",
    "(starting)" : "(iniziando)",
    "Fill template fields" : "Compila i campi del modello",
    "Submitting fields …" : "Invio dei campi …",
    "Submit" : "Invia",
    "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Transfer" : "Trasferisci",
    "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Unknown error" : "Errore sconosciuto",
    "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
    "Cannot transfer ownership of a file or folder you do not own" : "Impossibile trasferire la proprietà di un file o di una cartella di cui non sei proprietario",
    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Change" : "Modifica",
    "New owner" : "Nuovo proprietario",
    "Keep {old}" : "Mantieni {old}",
    "Keep without extension" : "Mantenere senza estensione",
    "Use {new}" : "Usa {new}",
    "Remove extension" : "Rimuovi estensione",
    "Change file extension" : "Cambia estensione file",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Modificando l'estensione del file da \"{old}\" a\"{new}\" potrebbe rendere il file illeggibile.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Rimuovendo dell'estensione del file \"{old}\" potrebbe rendere il file illeggibile.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Aggiungere l'estensione del file \"{new}\" potrebbe rendere il file illeggibile.",
    "Do not show this dialog again." : "Non visualizzare più questa finestra di dialogo.",
    "Cancel" : "Annulla",
    "Rename" : "Rinomina",
    "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
    "Choose {file}" : "Scegli {file}",
    "Files settings" : "Impostazioni File",
    "Switch to list view" : "Passa alla vista elenco",
    "Switch to grid view" : "Passa alla vista griglia",
    "The file could not be found" : "Il file non è stato trovato",
    "Upload was cancelled by user" : "Caricamento annullato dall'utente",
    "Not enough free space" : "Spazio libero insufficiente",
    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
    "Error during upload: {message}" : "Errore durante il caricamento: {message}",
    "Error during upload, status code {status}" : "Errore durante il caricamento, codice di stato {status}",
    "Unknown error during upload" : "Errore sconosciuto durante il caricamento",
    "Loading current folder" : "Sto caricando la cartella corrente",
    "Retry" : "Riprova",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
    "Go back" : "Indietro",
    "Views" : "Viste",
    "Loading …" : "Caricamento in corso...",
    "Your files" : "I tuoi files",
    "Open in files" : "Apri in file",
    "File cannot be accessed" : "Il file non possono essere acceduti",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Impossibile trovare il file oppure non disponi dei permessi per visualizzarlo. Chiedi al mittente di condividerlo.",
    "No search results for “{query}”" : "Nessun risultato di ricerca per “{query}”",
    "Search for files" : "Cerca file",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
    "Failed to toggle Windows filename support" : "Impossibile attivare il supporto per i nomi file di Windows",
    "Files compatibility" : "Compatibilità di File",
    "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
    "Blank" : "Vuoto",
    "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
    "Pick a template for {name}" : "Scegli un modello per {name}",
    "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
    "Creating file" : "Creazione del file",
    "Save as {displayName}" : "Salva come {displayName}",
    "Save as …" : "Salva come …",
    "Converting files …" : "Conversione dei file …",
    "Failed to convert files: {message}" : "Impossibile convertire i file: {message}",
    "All files failed to be converted" : "Non è stato possibile convertire tutti i file",
    "One file could not be converted: {message}" : "Un file non può essere convertito: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n file non può essere convertito","%n file non possono essere convertiti","%n file non possono essere convertiti"],
    "_%n file converted_::_%n files converted_" : ["%n file convertito","%n file convertiti","%n file convertiti"],
    "Files converted" : "File convertiti",
    "Failed to convert files" : "Impossibile convertire i file",
    "Converting file …" : "Conversione del file …",
    "File successfully converted" : "File convertito con successo",
    "Failed to convert file: {message}" : "Impossibile convertire il file: {message}",
    "Failed to convert file" : "Impossibile convertire il file",
    "Delete" : "Elimina",
    "Leave this share" : "Abbandona questa condivisione",
    "Leave these shares" : "Abbandona queste condivisioni",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Disconnect storages" : "Disconnetti il supporto di archiviazione",
    "Delete permanently" : "Elimina permanentemente",
    "Delete and unshare" : "Elimina e annulla la condivisione",
    "Delete file" : "Elimina file",
    "Delete files" : "Elimina i file",
    "Delete folder" : "Elimina cartella",
    "Delete folders" : "Elimina la cartella",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Stai per eliminare permanentemente {count} elemento","Stai per eliminare permanentemente {count} elementi","Stai per eliminare permanentemente {count} elementi"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Stai per eliminare {count} elemento","Stai per eliminare {count} elementi","Stai per eliminare {count} elementi"],
    "Confirm deletion" : "Conferma l'eliminazione",
    "Download" : "Scarica",
    "The requested file is not available." : "Il file richiesto non è disponibile.",
    "The requested files are not available." : "I file richiesti non sono disponibili.",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add or remove favorite" : "Aggiungi o rimuovi preferito",
    "Move" : "Sposta",
    "Copy" : "Copia",
    "Move or copy" : "Sposta o copia",
    "Destination is not a folder" : "La destinazione non è una cartella",
    "This file/folder is already in that directory" : "Questo file/cartella è già in quella cartella",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
    "A file or folder with that name already exists in this folder" : "Esiste già un file o una cartella con quel nome in questa cartella",
    "The files are locked" : "I files sono bloccati",
    "The file does not exist anymore" : "Il file non esiste più",
    "Moving \"{source}\" to \"{destination}\" …" : "Spostare \"{source}\" in \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiare \"{source}\" in \"{destination}\" …",
    "Choose destination" : "Scegli la destinazione",
    "Copy to {target}" : "Copia in {target}",
    "Move to {target}" : "Sposta in {target}",
    "Move or copy operation failed" : "Operazione di spostamento o copia fallita",
    "Open folder" : "Apri cartella",
    "Open folder {displayName}" : "Apri la cartella {displayName}",
    "Open in Files" : "Apri in File",
    "Open locally" : "Aprire localmente",
    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
    "Open file locally" : "Apri file localmente",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'applicazione desktop.",
    "Retry and close" : "Riprova e chiudi",
    "Open online" : "Apri online",
    "Details" : "Dettagli",
    "Open the details sidebar" : "Apri la barra laterale dei dettagli",
    "Unfavorite" : "Rimuovi preferito",
    "View in folder" : "Visualizza nella cartella",
    "Type" : "Tipo",
    "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
    "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
    "Create templates folder" : "Crea cartella dei modelli",
    "Templates" : "Modelli",
    "New template folder" : "Nuova cartella dei modelli",
    "In folder" : "Nella cartella",
    "Pick folder to search in" : "Seleziona la cartella in cui cercare",
    "Search in all files" : "Cerca in tutti i file",
    "Search in folder: {folder}" : "Cerca nella cartella: {folder}",
    "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file depositati",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Il tuo browser non supporta l'API del file system. Le directory non verranno caricate",
    "No files to upload" : "Nessun file da caricare",
    "Unable to create the directory {directory}" : "Impossibile creare la cartella {directory}",
    "Some files could not be uploaded" : "Alcuni file non possono essere caricati",
    "Files uploaded successfully" : "Files caricati correttamente",
    "No files to process" : "Nessun file da elaborare",
    "Files copied successfully" : "File copiati correttamente",
    "Files moved successfully" : "File spostati correttamente",
    "Some files could not be copied" : "Alcuni file non possono essere copiati",
    "Some files could not be moved" : "Alcuni file non possono essere spostati",
    "Conflicts resolution skipped" : "Risoluzione dei conflitti saltata",
    "Upload cancelled" : "Caricamento annullato",
    "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This folder is unavailable, please try again later or contact the administration" : "Questa cartella non è disponibile, riprova più tardi o contatta l'amministrazione",
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Unexpected error: {error}" : "Errore imprevisto: {error}",
    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
    "_%n hidden_::_%n hidden_" : ["%n nascosto","%n nascosti","%n nascosti"],
    "Filename must not be empty." : "Il nome del file non può essere vuoto.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" non è consentito in un nome di file.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" è un nome riservato e non consentito per i nomi di file.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" non è un tipo di file consentito.",
    "Filenames must not end with \"{extension}\"." : "I nomi di file non possono terminare con \"{extension}\".",
    "List of favorite files and folders." : "Elenco dei file e delle cartelle preferiti.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "List of your files and folders." : "Lista dei tuoi file e cartelle.",
    "Folder tree" : "Albero delle cartella",
    "List of your files and folders that are not shared." : "Elenco dei file e delle cartelle che non sono condivisi.",
    "No personal files found" : "Nessun file personale trovato",
    "Files that are not shared will show up here." : "I file che non vengono condivisi verranno visualizzati qui.",
    "Recent" : "Recenti",
    "List of recently modified files and folders." : "Lista di file e cartelle modificati di recente.",
    "No recently modified files" : "Nessun file modificato di recente",
    "Files and folders you recently modified will show up here." : "I file e le cartelle che hai modificato di recente saranno mostrati qui.",
    "Search" : "Cerca",
    "Search results within your files." : "Cerca i risultati all'interno dei tuoi file.",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "%1$s (renamed)" : "%1$s (rinominato)",
    "renamed file" : "file rinominato",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "È anche possibile migrare i file automaticamente dopo aver abilitato questa impostazione; fare riferimento alla documentazione relativa al comando occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
    "Clear filter" : "Pulisci il filtro",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" non riuscito su alcuni elementi",
    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
    "Submitting fields …" : "Invio dei campi …",
    "Shared by link" : "Condivisi tramite collegamento",
    "Shared" : "Condiviso",
    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
    "Filter file names …" : "Filtra i nomi dei file …",
    "Clipboard is not available" : "Appunti non disponibili",
    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
    "Enable the grid view" : "Attiva visuale a griglia",
    "Enable folder tree" : "Abilita l'albero delle cartelle",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copia negli appunti",
    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
    "Prevent warning dialogs from open or reenable them." : "Impedire l'apertura delle finestre di dialogo di avviso o riattivarle.",
    "Show a warning dialog when changing a file extension." : "Mostra una finestra di dialogo di avviso quando si modifica l'estensione di un file.",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Speed up your Files experience with these quick shortcuts." : "Velocizza la tua esperienza con i File con queste rapide scorciatoie.",
    "Open the actions menu for a file" : "Aprire il menu delle azioni per un file",
    "Rename a file" : "Rinominare un file",
    "Delete a file" : "Eliminare un file",
    "Favorite or remove a file from favorites" : "Aggiungere ai Preferiti o rimuovere un file dai preferiti",
    "Manage tags for a file" : "Gestire i tag per un file",
    "Deselect all files" : "Deseleziona tutti i file",
    "Select or deselect a file" : "Seleziona o deseleziona un file",
    "Select a range of files" : "Seleziona un intervallo di file",
    "Navigate to the parent folder" : "Passare alla cartella padre",
    "Navigate to the file above" : "Vai al file sopra",
    "Navigate to the file below" : "Vai al file qui sotto",
    "Navigate to the file on the left (in grid mode)" : "Navigare nel file a sinistra (in modalità griglia)",
    "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
    "Toggle the grid view" : "Attiva la vista a griglia",
    "Open the sidebar for a file" : "Aprire la barra laterale per un file",
    "You" : "Tu",
    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
    "Unable to change the favorite state of the file" : "Impossibile modificare lo stato preferito del file",
    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
    "Tags" : "Etichette",
    "Save as …" : "Salva come …",
    "Converting files …" : "Conversione dei file …",
    "Converting file …" : "Conversione del file …",
    "Deletion cancelled" : "Eliminazione annullata",
    "Edit locally" : "Modifica localmente",
    "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
    "(copy)" : "(copia)",
    "(copy %n)" : "(copia %n)",
    "Move cancelled" : "Spostamento annullato",
    "Cancelled move or copy of \"{filename}\"." : "Spostamento o copia di \"{filename}\" annullato.",
    "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
    "Open details" : "Apri i dettagli",
    "Photos and images" : "Foto e immagini",
    "New folder creation cancelled" : "Creazione nuova cartella annullata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "All folders" : "Tutte le cartelle",
    "Open file sidebar" : "Apri la barra laterale del file",
    "Search everywhere …" : "Cerca ovunque…",
    "Search here …" : "Cerca qui…",
    "Preparing …" : "In preparazione …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
